pip
===

`User list <https://groups.google.com/forum/#!forum/python-virtualenv>`_ |
`Dev list <https://groups.google.com/forum/#!forum/pypa-dev>`_ |
`GitHub <https://github.com/pypa/pip>`_ |
`PyPI <https://pypi.org/project/pip/>`_ |
User IRC: #pypa |
Dev IRC: #pypa-dev

The `PyPA recommended <https://packaging.python.org/en/latest/current/>`_ tool
for installing Python packages.

.. toctree::
   :maxdepth: 1

   quickstart
   installing
   user_guide
   reference/index
   development/index
   news
